##  Finding the Workspace ID
When configuring integrations and working with APIs, you may need the workspace ID. To find the workspace ID, navigate to the API Tokens section in the administration area and locate the WorkspaceId value.
